import { Observable } from 'rxjs/Rx';
/**
 * This injectable service can optionally be provided to the ObservableClient or ObservableClientBase classes included
 * in this library in order to provide you with a stream of http call status represented as IClientEvent emissions.
 *
 * The spy (ClientObserver) is designed to allow you to feed client events into the progress service to update the
 * state of your progress bar component, both of which are also included in this library.
 *
 * ### Simple Example
 *
 * Add service to your app module so it can be injected into your components
 *
 * ```
 * import { Ng2UEUtilsModule, ClientObserver } from 'ng2-ue-utils';
 * import { AppComponent } from './path/to/appComponent';
 * import { MyComponent } from './path/to/myComponent';
 *
 * @NgModule({
 *   bootstrap:     [ AppComponent ],
 *   declarations:  [ AppComponent, MyComponent ],
 *   imports:       [ Ng2UEUtilsModule ],
 *   providers:     [ ClientObserver ]
 * })
 * ```
 *
 * And in myComponent.ts
 * ```
 * import { ClientObserver } from 'ng2-ue-utils';
 *
 * @Component({
 *     selector: 'my-component',
 *     template: `<div> my content </div>`
 * })
 * class MyComponent {
 *
 *     constructor(private progressService: ProgressService, private spy: ClientObserver){}
 *
 *     private subscribeToServerCallsEvents () {
 *       this.spy.clientEvents
 *          .filter(status => status.event !== 'next')
 *          .subscribe((event: IClientEvent) => {
 *               this.progressService.notify(event);
 *           });
 *     }
 * }
 * ```
 */
export declare type ClientEvent = 'error' | 'start' | 'complete' | 'next';
export declare type ClientMethod = 'get' | 'put' | 'post' | 'delete';
export interface IClientEvent {
    stackCount: number;
    event: ClientEvent;
    method: ClientMethod;
    error?: any;
}
export declare class ClientObserver {
    private _emitter;
    private _stackCount;
    clientEvents: Observable<IClientEvent>;
    private countUp;
    private countDown;
    emitChange: (event: ClientEvent, method: ClientMethod, error?: any) => void;
    observeOn: <T>(method: ClientMethod, obs: Observable<T>) => Observable<T>;
}
